######################################
######### Chapter 5 #################
######################################

## Setting up RStudio Project 


## Downloading Dataset


## Installing R Packages for Data Importing

install.packages(c("readr", "readxl", "haven", "rio", "gapminder", "wbstats"), dependencies = TRUE)

## Importing Downloaded Dataset in RStudio

### Importing Dataset By Point-and-Click


###  Importing Downloaded Dataset Using Code
# Note how the path to data file must be specified in this stand-alone R proram
# you must replace this path with the appropriate one on your computer
# But in the book, an RStudio project was already specified first 
# so that reference to the path to the file is implied in the RMarkdown document

library(readxl)
Indicator_Average_age <- read_excel("C:\\Users\\Quan Li\\Dropbox\\491\\sage\\code.data\\data\\Indicator_Average age.xlsx")

### Choosing between Point-and-Click and Using Code


### Getting to Know Your Data: Initial Check

# Examine your data in viewer
View(Indicator_Average_age)

# list variable names
names(Indicator_Average_age)

# show descriptive statistics
summary(Indicator_Average_age)

# load tibble packge
library(tibble)

# show dataset information
as_tibble(Indicator_Average_age)

# load packge
library(dplyr)
library(magrittr)

# change variable names
Indicator_Average_age <- Indicator_Average_age %>%
    rename(country = "Average age of billionaires",
           ave.age.2004 = "2004.0",
           ave.age.2005 = "2005.0",
           ave.age.2006 = "2006.0",
           ave.age.2007 = "2007.0")       

# double check new variable names
names(Indicator_Average_age)

# replace all zero values with NA
Indicator_Average_age <- na_if(Indicator_Average_age, 0)

# check missing value recoding
as_tibble(Indicator_Average_age)

summary(Indicator_Average_age)

## Using R Data Packages: A Simple Example with **gapminder**

### Installing the gapminder Data Package


### Loading the gapminder Data Package

# load the data package
library(gapminder)

# load and view the data
data("gapminder")

# list variable names
names(gapminder)

# compute summary statistics for each variable
summary(gapminder)
 
# load tibble packge
library(tibble)

# show dataset information
as_tibble(gapminder)

## Using R Data Packages: A More Advanced Example with **wbstats**


### **wbstats** Overview
# load wbstats package
library(wbstats)

# 1. How many countries and regions are covered? What other auxiliary variables are included??
# create a dataframe called countries
countries <- wbcountries(lang="en")

# load tibble package
library(tibble)

# show dataset information
as_tibble(countries)

# 2. How many indicators are covered? 
# create a dataframe for list of indicators
indicators <- wbindicators(lang="en")

# show dataset information
as_tibble(indicators)

# 3. How many data sources are covered? 
# create a dataframe for list of data sources
sources <- wbsources(lang="en")

# show dataset information
as_tibble(sources)

# 4. How many types of topics are covered? 
# create a dataframe for list of topics
topics <- wbtopics(lang="en")

# show dataset information
as_tibble(topics)

### How Do You Extract Data from **wbstats**?
# 1. determine your question of interest and the scope of your data

# 2. Find the variable of interest
# create dataset for internet-related indicators
internet <- wbsearch(pattern = "internet", fields = "indicator")

# load knitr package
library(knitr)

# make a table of search results
kable(internet, row.names = FALSE)

# show search results in viewer
View(internet)

# 3. Use the wb() function to specify the variable, as well as the time and space scope for the variable, extract the data, and then assign the extracted data to a new dataframe
# extract data of interest
internet_pop <- wb(indicator = "IT.NET.USER.ZS", country = "countries_only", mrv=1)

# 4. Show information of the extracted dataset
# show dataset information
as_tibble(internet_pop)
summary(internet_pop)

# 5. Exploring the data to answer your question about digital divide
# create a histogram for internet use
hist(internet_pop$value, 
            xlab="% internet users in population",
            main="Percent of Internet Users in Population: 204 Countries, 2017")


