######################################
######### Chapter 6 #################
######################################

# Exploratory Data Analysis: Three Exercises {#analysis}
# install a needed package
# installation only needs to be run once and then to be commented out
install.packages("gridExtra", dependencies=TRUE)


## Exercise 1: Reporting Results of 2016 Presidential Primary in King County, Washington

### Context and Motivation  

### Preparation: Setting up an RStudio Project, Downloading, and Checking Data

# load data importing package
library(readr)

# create a dataset object
# Note how the path to data file must be specified in this stand-alone R proram
# you must replace this path with the appropriate one on your computer
# But in the book, an RStudio project was already specified first 
# so that reference to the path to the file is implied in the RMarkdown document

primary2016 <- read_csv("C:\\Users\\Quan Li\\Dropbox\\491\\sage\\code.data\\data\\2016_Presidential_Primary_-_Election_Results_by_precinct__complete_eCanvass_dataset_.csv")

# check variable names
names(primary2016)

# summary statistics
summary(primary2016)

# dataset overview
library(tidyverse)
as_tibble(primary2016)

# dataset overview
as.data.frame(head(primary2016))

# list candidates in CounterType variable
primary2016 %>%
  count(CounterType)

### Reporting Results for the Republican Primary

# create new data for Republican primary
rep2016 <- primary2016 %>%
  filter(CounterType=="Ben Carson" | 
         CounterType=="Donald J. Trump" |
         CounterType=="John R. Kasich" |
         CounterType=="Ted Cruz" ) %>%
  rename(candidate = CounterType) %>%
  group_by(candidate)  %>%
  summarise(vote = sum(SumOfCount)) 

# display the results
rep2016

#### Graphical Display of Results for Republican Primary: Introducing ggplot2

#(1) Display using barplot()
# graphically compare the candidates
rep2016 %>% 
  with(barplot(vote, names.arg = candidate,
       main = "Republican Primary in King County, Washington, 2016",
       ylab = "Number of Votes"))

# (2) Display using ggplot2
# graphically compare the candidates
rep2016 %>%
  ggplot(aes(candidate, vote)) +
  geom_bar(stat="identity") +
  geom_text(aes(label=vote)) +
  labs(title = "Republican Primary in King County, Washington, 2016",
              x = "Republican Candidates",
              y = "Number of Votes")

### Reporting Results for the Democratic Primary

# create new data for Democratic primary
dem2016 <- primary2016 %>%
  filter(CounterType=="Bernie Sanders" |
         CounterType=="Hillary Clinton") %>%
  rename(candidate = CounterType) %>%
  group_by(candidate)  %>%
  summarise(vote = sum(SumOfCount)) 

# display the results
dem2016

#### Graphical Display of Results for Democratic Primary

# graphically compare the candidates
dem2016 %>%
  ggplot(aes(candidate, vote)) +
  geom_bar(stat="identity", width = 0.5) +
  geom_text(aes(label=vote)) +
  labs(title = "Democratic Primary in King County, Washington, 2016",
              x = "Democratic Candidates",
              y = "Number of Votes") 

## Exercise 2: Human Use of Natural Resources: Consumption and Biocapacity

### Context and Motivation  


### Preparation: Setting up an RStudio Project, Downloading, and Checking Data

# 1. Following the examples in Chapter 1 or 5, create an RStudio project
# 2. Download two datasets: `NFA 2018 Edition.csv`  and `Data dictionary` 
# from here <https://data.world/footprint/nfa-2018-edition/workspace/data-dictionary>

# 3. read the downloaded daa into R
# load data importing package
library(readr)

# create a dataset object
# Note how the path to data file must be specified in this stand-alone R proram
# you must replace this path with the appropriate one on your computer
# But in the book, an RStudio project was already specified first 
# so that reference to the path to the file is implied in the RMarkdown document

nfa2018 <- read_csv("C:\\Users\\Quan Li\\Dropbox\\491\\sage\\code.data\\data\\NFA 2018 Edition.csv")

# 4. carry out an initial data check
# check variable names
names(nfa2018)

# summary statistics
summary(nfa2018)

# dataset overview
library(tidyverse)
as_tibble(nfa2018)

# dataset overview
as.data.frame(head(nfa2018, n=8))

# list categories in record variable
nfa2018 %>%
  count(record)

# 5. 4. answer the questions raised at the beginning of the section
# load the packages needed
library(magrittr)
library(tidyverse)

# create dataset with country year and a few variables
nfa2018.new <- nfa2018 %>%
  filter(record=="BiocapPerCap" | record=="EFConsPerCap") %>%
  select(country, year, record, total)  

### Question 1: What are the Temporal Patterns of Resource Consumption and Biocapacity of our World?

nfa2018.new %>%
  filter(country=="World") %>%
  ggplot(aes(x=year, y=total, linetype=record)) +           
         geom_line() +
         labs(title = "Ecological Footprint of Consumption and Biocapacity for Our World",
              y = "global hectares per person")

### Question 2: Do the U.S. and China Differ in their Patterns of Resource Consumption and Biocapacity?

nfa2018.new %>%
  filter(country=="United States of America" | country=="China") %>%
  ggplot(aes(x=year, y=total, linetype=record)) +           
         geom_line() +
         facet_wrap(~ country) + 
         labs(title = "Ecological Footprint of Consumption and Biocapacity in US and China",
              y = "global hectares per person") +
         theme(legend.position="bottom")

# create dataset with country year and a few variables
nfa2018 %>%
  filter(record=="BiocapTotGHA" | record=="EFConsTotGHA") %>%
  filter(country=="United States of America" | country=="China") %>%
  select(country, year, record, total) %>%
  ggplot(aes(x=year, y=total, linetype=record)) +           
         geom_line() +
         facet_wrap(~ country) + 
         labs(title = "Ecological Footprint of Consumption and Biocapacity in US and China",
              y = "total global hectares") +
         theme(legend.position="bottom")


### Question 3: Does Resource Consumption Remain Similar or Differ across Various Types of Ecological Footprint of Consumption?

# create dataset with country year and a few variables
US <- nfa2018 %>%
  filter(record=="EFConsTotGHA" & country=="United States of America") 

# combine multiple plots
# Note: You may get an error message if your plot panel in RStudio is too small
# you could expand your plot panel
par(mfrow=c(3,2))
with(US, {
  plot(year, crop_land, type="b")
  plot(year, grazing_land, type="b")
  plot(year, forest_land, type="b")
  plot(year, fishing_ground, type="b")
  plot(year, built_up_land, type="b")
  plot(year, carbon, type="b")
  })
par(mfrow=c(1,1))


## Exercise 3: Exploring the Impact of GDP Per Capita on Life Expectancy

### Context and Motivation  

### Preparation: Setting up an RStudio Project, Downloading, and Checking Data

# 1. create an RStudio project 
# 2. Follow the **wbstats** example in Chapter 5
# load wbstats package
library(wbstats)
library(knitr)

# list related indicators and their id
wbsearch(pattern = "GDP per capita|life expectancy at birth" , fields = "indicator") %>%
kable(row.names = FALSE)

# 3. extract data of interest
life.exp <- wb(indicator = c("SP.DYN.LE00.IN", "SP.DYN.LE00.MA.IN", "SP.DYN.LE00.FE.IN", "NY.GDP.PCAP.KD"), 
                   country = "countries_only", 
                   startdate=1970, enddate=2010)

# 4. carry out an initial data check: variable names, summary statistics, and dataset overview.
# check variable names
names(life.exp)

# summary statistics
summary(life.exp)

# dataset overview
as_tibble(life.exp)

# dataset overview
as.data.frame(head(life.exp, n=8))

# 5. Data re-organization or tidying 
# re-organize and overwrite old dataset
life.exp <- life.exp %>%
  select(country, date, value, indicator) %>%
  mutate(date = as.numeric(date))  %>%
  spread(indicator, value) %>%
  rename(gdppc = "GDP per capita (constant 2010 US$)",
           life.total = "Life expectancy at birth, total (years)",
           life.m = "Life expectancy at birth, male (years)",
           life.f = "Life expectancy at birth, female (years)",
         year = "date")  %>%
  filter(year==1970 | year==1980 | year==1990 | year==2000 | year==2010)

# dataset overview
as_tibble(life.exp)

# 6. Save the prepared R data frame as a stand-alone R dataset
# save R data file
# Note how the path to data file must be specified in this stand-alone R proram
# you must replace this path with the appropriate one on your computer
# But in the book, an RStudio project was already specified first 
# so that reference to the path to the file is implied in the RMarkdown document

save(life.exp, file = "C:\\Users\\Quan Li\\Dropbox\\491\\sage\\code.data\\data\\life.exp.RData")

# 7. prepare a codebook for your dataset
tabl <- "  
|	variable	|	definition	|	source	|
|	----	|---------		|---		|
|	iso3c	|	country code	|	wbstats	|
|	country	|	country name	|	wbstats	|
|	year	|	year 	|	wbstats	|
|	gdppc	|	GDP per capita (constant 2010 US$)	|	wbstats	|
|	life.f	|	Life expectancy at birth, female (years)	|	wbstats	|
|	life.m	|	Life expectancy at birth, male (years)	|	wbstats	|
|	life.total	|	Life expectancy at birth, total (years)	|	wbstats	|"
cat(tabl) 

# summary statistics for life.exp
summary(life.exp)


### Exploring the Relationship between Economic Development and Life Expectancy

#### Preparation before Exploration

# load R data file
# Note how the path to data file must be specified in this stand-alone R proram
# you must replace this path with the appropriate one on your computer
# But in the book, an RStudio project was already specified first 
# so that reference to the path to the file is implied in the RMarkdown document
load("C:\\Users\\Quan Li\\Dropbox\\491\\sage\\code.data\\data\\life.exp.RData")

# load package for combining plots
library(gridExtra)
library(magrittr)
library(ggplot2)
library(tidyverse)

# histograms for distribution
life.t.hist <- life.exp %>%
                  ggplot(aes(life.total)) +           
                  geom_histogram() 

gdppc.hist <- life.exp %>%
                  ggplot(aes(gdppc)) +           
                  geom_histogram() 

# combine two histograms side by side
grid.arrange(life.t.hist, gdppc.hist, ncol=2)

#### Visualizing the Relationship Using Scatter Plot

# 1. Look for a possible overall relationship across five decades
# scatter plot for gdppc and life.total
life.exp %>%
  ggplot(aes(x=gdppc, y=life.total)) +           
         geom_point() + 
         labs(title = "Scatter Plot of GDP per capita and Life Expectancy at Birth",
              x = "GDP per capita (constant 2010 US$)",
              y = "life expectancy at birth") 

# 2. Is it possible that the pattern is different between men and women?
# load package for combining plots
library(gridExtra)

# plots for men and women
men <- life.exp %>%
  ggplot(aes(x=gdppc, y=life.m)) +           
         geom_point() + 
         labs(title = "Man",
              x = "GDP per capita",
              y = "men's life expectancy at birth") 


women <- life.exp %>%
  ggplot(aes(x=gdppc, y=life.f)) +           
         geom_point() +
         labs(title = "Women",
              x = "GDP per capita",
              y = "women's life expectancy at birth") 

# combine two plots and add a title
grid.arrange(men, women, ncol=2, top="GDP per capita and Life Expectancy")

# 3. Could it be possible that the non-linear positive relationship between GDP per capita and life expectancy changes over time?
# plot gdppc and life.total by year
life.exp %>%
  ggplot(aes(x=gdppc, y=life.total)) +           
         geom_point() + 
         facet_wrap(~ year) +
         labs(title = "Scatter Plot of GDP per capita and Life Expectancy by Year",
              x = "GDP per capita (constant 2010 US$)",
              y = "life expectancy at birth") 

# 4. Could it be possible that the non-linear positive relationship between GDP per capita and life expectancy is affected by the skewed distributions of the two variables?
# plot gdppc and life.total
p1 <-life.exp %>%
  ggplot(aes(x=gdppc, y=log(life.total))) +           
         geom_point() + 
         labs(title = "GDP per capita and Logged Life Expectancy at Birth",
              x = "GDP per capita (constant 2010 US$)",
              y = "logged life expectancy at birth") 

# plot gdppc and life.total
p2 <- life.exp %>%
  ggplot(aes(x=log(gdppc), y=life.total)) +           
         geom_point() + 
         labs(title = "Logged GDP per capita and Life Expectancy at Birth",
              x = "Logged GDP per capita (constant 2010 US$)",
              y = "life expectancy at birth") 

# plot gdppc and life.total
p3 <- life.exp %>%
  ggplot(aes(x=log(gdppc), y=log(life.total))) +           
         geom_point() + 
         labs(title = "Logged GDP per capita and Logged Life Expectancy at Birth",
              x = "Logged GDP per capita (constant 2010 US$)",
              y = "Logged life expectancy at birth") 

# combine plots
grid.arrange(p1, p2, p3)


#### Computing Correlation Coefficient between GDP per capita and Life Expectancy

# 1. Starting with the sample correlation between GDP per capita and life expectancy across the decades.

#	sample correlation coefficient, non-missing observations
life.exp %>%
  summarize(correlation=cor(gdppc, life.total, use="complete.obs")) 

# 2. Gender difference. The code and output below compare the correlation of GDP per capita with life expectancy for male and female, respectively. 

life.exp %>%
  summarize(male = cor(gdppc, life.m, use="complete.obs"), 
            female = cor(gdppc, life.f, use="complete.obs")
            ) 

#3. Changes in correlation over time. The code and output below compute the sample correlation between GDP per capita and life expectancy for each year across five decades. Notice how the `group_by()` function is used for this purpose.

life.exp %>%
  group_by(year) %>%
  summarize(correlation=cor(gdppc, life.total, use="complete.obs"))

#4. Sample correlation based on log transformed variable(s).

# log transformation and correlation
life.exp %>%
  summarize(log.life = cor(gdppc, log(life.total), use="complete.obs"),
            log.gdppc = cor(log(gdppc), life.total, use="complete.obs"),
            log.both = cor(log(gdppc), log(life.total), use="complete.obs")
            ) 

#### Estimating the Effect of GDP per capita on Life Expectancy Using Regression

#1. Starting with the estimation results between GDP per capita and life expectancy across the decades.

# estimate regression model
  lm(life.total ~ gdppc, data = life.exp) 

#2. Gender difference. The code should be same as above, except that the dependent variable should be `life.m` for male and `life.f` for female.

# estimate regression model
  lm(life.m ~ gdppc, data = life.exp) 
  lm(life.f ~ gdppc, data = life.exp) 

#3. Changes in the marginal effect over time. The code remains as earlier, with one exception. To estimate a model for each year, added to the `data=life.exp` option is a sample selection condition. After the dataframe name is  `[life.exp$year==1970,]` for 1970 etc. The bracket is one way for R to index rows/observations and columns/variables, with rows placed first, and variables after. `data = life.exp[life.exp$year==1970,]` means that estimation applies to observations for which year equals 1970 only and the empty space after comma means that no variable needs to be excluded.

# estimate regression model
  lm(life.total ~ gdppc, data = life.exp[life.exp$year==1970,]) 
  lm(life.total ~ gdppc, data = life.exp[life.exp$year==1980,])
  lm(life.total ~ gdppc, data = life.exp[life.exp$year==1990,]) 
  lm(life.total ~ gdppc, data = life.exp[life.exp$year==2000,])
  lm(life.total ~ gdppc, data = life.exp[life.exp$year==2010,]) 


#4. Marginal effect based on log tranformed variable(s).

  # estimate regression model
  lm(log(life.total) ~ gdppc, data = life.exp) 
  lm(life.total ~ log(gdppc), data = life.exp) 
  lm(log(life.total) ~ log(gdppc), data = life.exp) 

  