######################################
######### Chapter 7 #################
######################################

# install a needed package
# installation only needs to be run once and then to be commented out
install.packages(c("stargazer", "summarytools"), dependencies=TRUE)


# load package
library(knitr)
library(tidyverse)
library(magrittr)
library(ggplot2)

# load R data file
# Note how the path to data file must be specified in this stand-alone R proram
# you must replace this path with the appropriate one on your computer
# But in the book, an RStudio project was already specified first 
# so that reference to the path to the file is implied in the RMarkdown document
load("C:\\Users\\Quan Li\\Dropbox\\491\\sage\\code.data\\data\\life.exp.RData")

# load package for combining plots
library(gridExtra)

# histograms for distribution
life.t.hist <- life.exp %>%
                  ggplot(aes(life.total)) +           
                  geom_histogram() 

gdppc.hist <- life.exp %>%
                  ggplot(aes(gdppc)) +           
                  geom_histogram() 

# combine two histograms side by side
grid.arrange(life.t.hist, gdppc.hist, ncol=2)

# plot gdppc and life.total
life.exp %>%
  ggplot(aes(x=log(gdppc), y=log(life.total))) +           
         geom_point() + 
         labs(title = "Logged GDP per capita and Logged Life Expectancy at Birth",
              x = "Logged GDP per capita (constant 2010 US$)",
              y = "Logged life expectancy at birth") 

# log transformation and correlation
life.exp %>%
  summarize(log.both = cor(log(gdppc), log(life.total), use="complete.obs")) %>%
  kable(caption="Correlation of log.GDP.pc and log.life.expectancy")

# estimate regression model
model <-  lm(log(life.total) ~ log(gdppc), data = life.exp) 

# show results table
library(stargazer)
stargazer(model, type = "text", title="Table 2 Simple Regression Results", digits=4)


## Appendix: Summary Statistics and Codebook
tabl <- "  
|	variable	|	definition	|	source	|
|	----	|---------		|---		|
|	iso3c	|	country code	|	wbstats	|
|	country	|	country name	|	wbstats	|
|	year	|	year 	|	wbstats	|
|	gdppc	|	GDP per capita (constant 2010 US$)	|	wbstats	|
|	life.total	|	Life expectancy at birth, total (years)	|	wbstats	|"
cat(tabl) # output the table in a format good for HTML/PDF/docx conversion

# summary statistics for life.exp
library(summarytools)
life.exp %>%
  select(-c(life.m, life.f)) %>%
  descr()


